#
# spec file for package python-typer
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2021 Matthias Bach <marix@marix.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%{?sle15_python_module_pythons}

Name:           python-typer
Version:        0.9.0
Release:        150600.1.3
Summary:        Typer, build great CLIs. Easy to code. Based on Python type hints
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/tiangolo/typer
Source:         https://files.pythonhosted.org/packages/source/t/typer/typer-%{version}.tar.gz
Patch1:         set-proper-pythonpath-for-tutorial-script-tests.patch
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module rich}
BuildRequires:  %{python_module shellingham}
BuildRequires:  %{python_module typing_extensions}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click >= 7.1
Recommends:     python-colorama
Recommends:     python-rich
Recommends:     python-shellingham
BuildArch:      noarch
%python_subpackages

%description
Typer is a library for building CLI applications based on Python 3.6+ type hints.

Based on type hints, Typer enables great editor support and completion for developers.
With automatic help and completion, Typer makes CLIs easy to use for users.

This package provides the Typer Python package required to build and run Typer-based CLI applications.

%prep
%setup -q -n typer-%{version}
%autopatch -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# the completion tests fail as build runs in sh which is not supported
%pytest -k 'not test_show_completion and not test_install_completion'

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/typer
%{python_sitelib}/typer-%{version}*-info

%changelog
* Tue Oct 17 2023 marix@marix.org
- Fix sle15_python_module_python being on wrong line post spec
  auto-format.
* Tue Oct 17 2023 marix@marix.org
- add sle15_python_module_python
* Sun May  7 2023 marix@marix.org
- Update to upstream version 0.9.0
  * Add support for PEP-593 Annotated for specifying options and
    arguments.
  * Add support for custom types and parsers.
- Drop patch run-subprocesses-with-correct-python.patch that got
  included upstream.
* Thu Jan  5 2023 marix@marix.org
- Adapt set-proper-pythonpath-for-tutorial-script-tests.patch to
  also work for Python 3.11.
* Sun Nov  6 2022 marix@marix.org
- Update to upstream version 0.7.0
  * Make typer.run() not add completion scripts by default, it only
    makes sense in installed apps.
  * Add support for Python 3.11.
* Mon Jul 18 2022 marix@marix.org
- Update to upstream version 0.6.1
  * Adds deep integrations with Rich. If Rich is available, it will
    be used to show the content from --help options, validation
    errors, and even errors in apps.
  * Support for Rich Markup and Markdown in docstrings, CLI
    parameters, help, and epilog.
  * Fix type conversion for List and Tuple.
  * Fix context_settings for a Typer apps with a single command.
  * Fix setting FORCE_TERMINAL with colors.
- Refreshed patches
* Fri Jun 24 2022 marix@marix.org
- Add run-subprocesses-with-correct-python.patch to ensure tests
  aren't accidentally running subprocesses using the wrong Python
  version.
- Add set-proper-pythonpath-for-tutorial-script-tests.patch to fix
  issue with build failing due to import failures.
* Tue Jun 14 2022 marix@marix.org
- Update to upstream version 0.4.1
  * Fix import of get_terminal_size for Click 8.1.0 support.
- Switch from traditional setup.py installation to pyproject macros
  as upstream no longer ships its setup.py compability wrapper.
* Mon Aug 30 2021 marix@marix.org
- Update to upstream version 0.4.0
  * Add support for Click 8 while keeping compatibility with
    Click 7.
- Remove basic-click8-compat.patch as Click 8 compatibility is now
  provided upstream.
* Fri Jul 23 2021 marix@marix.org
- Resolve Typer no longer working since Click got bumped to version
  8.
  * This removes support for autocompletion.
- Add basic-click8-compat.patch
* Wed Apr 14 2021 marix@marix.org
- Properly specify package group.
- Suppress false-positive detection of empty file in rpmlint.
- Properly declare minimum version requirement vs. python-click to
  avoid broken installation on Leap.
* Tue Apr 13 2021 marix@marix.org
- Initial package release
